# Copyright 1994-2001 The MathWorks, Inc.
#
# File    : ert_msvc.tmf   $Revision: 1.25 $
#
# Abstract:
#	Real-Time Workshop template makefile used to create <model>.mak
#	file needed for Microsoft Visual C/C++ environement.
#
# 	Note that this template is automatically customized by the Real-Time
#	Workshop build procedure to create "<model>.mk" which then is
#       passed to nmake to produce <model>.mak
#
#       The following defines can be used to modify the behavior of the
#	build:
#    OPTS           - Additional user defines.
#    USER_SRCS      - Additional user sources, such as files needed by
#                     S-functions.
#    USER_INCLUDES  - Additional include paths
#                     (i.e. USER_INCLUDES="/I where-ever1 /I where-ever2")


#------------------------ Macros read by make_rtw -----------------------------
#
# The following macros are read by the Real-Time Workshop build procedure:
#
#  MAKECMD         - This is the command used to invoke the make utility
#  HOST            - What platform this template makefile is targeted for
#                    (i.e. PC or UNIX)
#  BUILD           - Invoke make from the Real-Time Workshop build procedure
#                    (yes/no)?
#  SYS_TARGET_FILE - Name of system target file.

MAKECMD         = nmake
HOST            = PC
BUILD           = yes
SYS_TARGET_FILE = nitert.tlc

#---------------------- Tokens expanded by make_rtw ---------------------------
#
# The following tokens, when wrapped with "|>" and "|<" are expanded by the
# Real-Time Workshop build procedure.
#
#  MODEL_NAME      - Name of the Simulink block diagram
#  MODEL_MODULES   - Any additional generated source modules
#  MAKEFILE_NAME   - Name of makefile created from template makefile <model>.mk
#  MATLAB_ROOT     - Path to were MATLAB is installed.
#  MATLAB_BIN      - Path to MATLAB executable.
#  S_FUNCTIONS     - List of additional S-function modules.
#  S_FUNCTIONS_LIB - List of S-functions libraries to link.
#  NUMST           - Number of sample times
#  TID01EQ         - yes (1) or no (0): Are sampling rates of continuous task
#                    (tid=0) and 1st discrete task equal.
#  BUILDARGS       - Options passed in at the command line.
#  MULTITASKING    - yes (1) or no (0): Is solver mode multitasking
#  INTEGER_CODE    - yes (1) or no (0): Is generated code purely integer
#  MAT_FILE        - yes (1) or no (0): Should mat file logging be done,
#                    if 0, the generated code runs indefinitely

MODEL           = exp6
MODULES         = 
MAKEFILE        = exp6.mk
MATLAB_ROOT     = C:\MATLAB6p1
MATLAB_BIN      = C:\MATLAB6p1\bin\win32
S_FUNCTIONS     = 
S_FUNCTIONS_LIB = 
NUMST           = 1
TID01EQ         = 0
BUILDARGS       = 
MULTITASKING    = 0
INTEGER_CODE    = 0
MAT_FILE        = 0
ONESTEPFCN      = 1
TERMFCN         = 0

#---------------------------- Tool Definitions -------------------------------

PERL   = $(MATLAB_ROOT)\sys\perl\win32\bin\perl

#------------------------------ Include Path ----------------------------------

MATLAB_INCLUDES = \
 /I \
 /I "$(MATLAB_ROOT)\rtw\c\ert" \
 /I "$(MATLAB_ROOT)\extern\include" \
 /I "$(MATLAB_ROOT)\simulink\include" \
 /I "$(MATLAB_ROOT)\rtw\c\src" \
 /I "$(MATLAB_ROOT)\rtw\c\libsrc"

# Additional includes

ADD_INCLUDES = \


INCLUDES = $(MATLAB_INCLUDES) $(ADD_INCLUDES) $(USER_INCLUDES) .

#----------------------------- Defines ----------------------------------------

OPTS =

DEFINES = /D MODEL=$(MODEL) /D "ERT" /D INTEGER_CODE=$(INTEGER_CODE) \
	  /D NUMST=$(NUMST) /D TID01EQ=$(TID01EQ) /D MT=$(MULTITASKING) \
          /D MAT_FILE=$(MAT_FILE) \
          /D ONESTEPFCN=$(ONESTEPFCN) \
	  /D TERMFCN=$(TERMFCN) \
          $(OPTS)

#----------------------------- Source Files -----------------------------------

!if $(INTEGER_CODE) == 1
ADD_SRCS =
!else
!if $(MAT_FILE) == 1
RTWLOG = rtwlog.c
!else
RTWLOG =
!endif
ADD_SRCS = $(RTWLOG) rt_nonfinite.c
!endif

REQ_SRCS  = $(MODEL).c $(MODULES) ert_main.c $(ADD_SRCS)
USER_SRCS =
CUSTLIB_SRCS = 

SRCS = $(REQ_SRCS) $(USER_SRCS) $(S_FUNCTIONS) $(CUSTLIB_SRCS)
OBJS = $(SRCS:.c=.ofile) phony.target.for.libsrc.objs

#--------------------------------- Rules --------------------------------------

$(MODEL).mak : $(MODEL).mki
	@$(PERL) $(MATLAB_ROOT)\rtw\c\tools\msvc_mak.pl \
		$(MATLAB_ROOT)\rtw\c\tools\msvc_tpl.mak \
		$(MODEL).mki
	@del $(MODEL).mki
	@if exist $(MODEL).dsw del $(MODEL).dsw
	@if exist $(MODEL).dsp del $(MODEL).dsp
	@echo ### Created $(MODEL).mak for use with Microsoft Visual C/C++

$(MODEL).mki ::
	@if exist $(MODEL).mki del $(MODEL).mki
	@echo Model           = $(MODEL)> $(MODEL).mki
	@echo RequiredDefines = $(DEFINES)>> $(MODEL).mki
	@echo IncludeDirs     = $(INCLUDES)>> $(MODEL).mki
        @echo AdditionalLibs  = $(EXT_LIB) $(S_FUNCTIONS_LIB)>> $(MODEL).mki
	@echo Sources:>> $(MODEL).mki

$(MODEL).mki :: $(OBJS)

{$(MATLAB_ROOT)\rtw\c\ert}.c.ofile :
	@echo $<>> $(MODEL).mki

{$(MATLAB_ROOT)\rtw\c\src}.c.ofile :
	@echo $<>> $(MODEL).mki

# Additional sources



!if $(INTEGER_CODE) == 1
phony.target.for.libsrc.objs :
	@for %%i in ($(MATLAB_ROOT)\rtw\c\libsrc\rt_satlib.c \
                     $(MATLAB_ROOT)\rtw\c\libsrc\rt_enab.c) do \
		echo %%i>> $(MODEL).mki
!else
phony.target.for.libsrc.objs :
	@for %%i in ($(MATLAB_ROOT)\rtw\c\libsrc\*.c) do \
		echo %%i>> $(MODEL).mki
!endif

{$(MATLAB_ROOT)/simulink/src}.c.ofile :
	@echo $<>> $(MODEL).mki

{..}.c.ofile :
	@echo $<>> $(MODEL).mki

.c.ofile :
	@echo $<>> $(MODEL).mki
